#include <Wire.h>

#define AHT10_ADDRESS 0x38

void setup() {
  Serial.begin(115200);
  // I2C kommunikáció inicializálása az új GPIO lábakkal
  Wire.begin(8, 9); // SDA = GPIO 8, SCL = GPIO 9
  delay(5000);
  Serial.println("AHT10 szenzor inicializálás...");
  // Automatikus kalibrálás
  Wire.beginTransmission(AHT10_ADDRESS);
  Wire.write(0xE1); // Inicializálás parancs
  Wire.write(0x08); // Paraméter bájt 1
  Wire.write(0x00); // Paraméter bájt 2
  Wire.endTransmission();
  delay(20); // Várakozás a kalibrálás befejezéséhez

  Serial.println("AHT10 szenzor inicializálva és kalibrálva.");
}

void loop() {
  Serial.println("Új ciklus");
  float temperature, humidity;
  readAHT10(&temperature, &humidity);

  Serial.print("Hőmérséklet: ");
  Serial.print(temperature);
  Serial.println(" °C");

  Serial.print("Páratartalom: ");
  Serial.print(humidity);
  Serial.println(" %");

  delay(5000); // Várakozás 5 másodpercig a következő mérés előtt
}

void readAHT10(float *temperature, float *humidity) {
  Wire.beginTransmission(AHT10_ADDRESS);
  Wire.write(0xAC); // Mérés indítása parancs
  Wire.write(0x33); // Paraméter bájt 1
  Wire.write(0x00); // Paraméter bájt 2
  Wire.endTransmission();
  delay(100); // Várakozás a mérés befejezéséhez

  Wire.requestFrom(AHT10_ADDRESS, 6);
  if (Wire.available() == 6) {
    uint8_t data[6];
    for (int i = 0; i < 6; i++) {
      data[i] = Wire.read();
    }

    uint32_t rawHumidity = ((uint32_t)data[1] << 12) | ((uint32_t)data[2] << 4) | (data[3] >> 4);
    uint32_t rawTemperature = ((uint32_t)data[3] & 0x0F) << 16 | ((uint32_t)data[4] << 8) | data[5];

    *humidity = ((float)rawHumidity / 1048576.0) * 100.0;
    *temperature = ((float)rawTemperature / 1048576.0) * 200.0 - 50.0;
  }
}
